from Globals import Persistent
from IntegerField import IntegerField
from OFS.CopySupport import CopySource

class FieldSheet(Persistent, CopySource):
    """A simple sheet for fields that define the edit screen.
    
    NOTE: derive subclasses in special Sheet modules; don't derive them
    along with the field class as you'll end up with weird import cycles.
    """
    def __init__(self):
	"""Create the sheet.
	"""
	# a list of field ids in this sheet
	self.fieldIds = []
	# a list of field objects in this sheet
	self.fieldList = []

	# add a single order field
	field = IntegerField("order",
			     "Order",
			     visual_length = 15,
			     visual_max_length = 15,
			     required = 1,
			     default = 15)
	field._setMessage('required_not_found',
			  "This field is required.")
	field._setMessage('not_integer',
			  "This field expects an integer.")
	self.addField(field)
	
    def addField(self, field):
	"""Add a field to this sheet.
	
	field - a field instance that should be on this sheet
                its id should be identical to the id of a property of the
                field instance that this sheet is going to be added to.
	"""
	# add field instance to list
	fieldList = self.fieldList
	fieldList.append(field)
	self.fieldList = fieldList

	# add field id to list
	fieldIds = self.fieldIds
	fieldIds.append(field.id)
	self.fieldIds = fieldIds

	# also set attribute for easy access
	setattr(self, field.id, field)
