from Field import Field, ValidationError
from cStringIO import StringIO
import string
import Utils

class ListField(Field):
    """Field that displays a list.
    """

    meta_type = "ListField"

    def __init__(self, id, title,
		 data=None, 
		 size=5, 
		 required=0, 
		 default=None):
	"""Initialize.
	id - id of field
	title - description of field
	"""
	Field.__init__(self, id, title)
	# set properties
	props = self.props
	props.data = data or []
	props.size = size
	props.required = required
	props.default = default
	self.props = props
	
	self._addMessage('required_not_found',
			 'Input required but no input given')

    def sqltype(self):
	return "text"

    def render(self, value):
	"""Render this field.
	"""
	props = self.props
	
	result = StringIO()
	for title, contents in props.data:
	    # if only contents is given, show contents
	    title = title or contents
	    # if only title is given, contents is title
	    contents = contents or title
	    argdict = {
		'value': contents,
		}
	    if value == contents:
		argdict['selected'] = None
	    
	    result.write(Utils.html_tag('option', argdict, title))
	    result.write("\n")
	    
	argdict = {
	    'size' : props.size,
	    'name' : self.fieldname,
	    }	
	return Utils.html_tag('select', argdict, result.getvalue())

    def process(self, REQUEST):
	"""Process what's entered.
	"""
	props = self.props
	if REQUEST.has_key(self.fieldname):
	    input = REQUEST[self.fieldname]
	else:
	    input = ""

	# check if data was entered while required
	input = string.strip(input)
	if props.required and input == "":
	    raise ValidationError, "required_not_found"

	REQUEST.set(self.fieldname, input)
