from Field import Field, ValidationError
from cStringIO import StringIO
import string
import Utils

class RadioField(Field):
    """Field that defines a group of radio buttons.
    """

    meta_type = "RadioField"

    def __init__(self, id, title,
		 data=None,  
		 required=0, 
		 default=None):
	"""Initialize.
	id - id of field
	title - description of field
	"""
	Field.__init__(self, id, title)
	# set properties
	props = self.props
	props.data = data or []
	props.required = required
	props.default = default
	self.props = props
	
	self._addMessage('required_not_found',
			 'Input required but no input given')

    def sqltype(self):
	return "text"

    def amount(self):
	"""Amount of radio buttons in this field.
	"""
	return range(len(self.props.data))
    
    def render_part(self, i, value):
	"""Return HTML representation for a single radio button.
	"""
	props = self.props
    
	# get data to display
	title, contents = props.data[i]
	# if only contents is given, show contents
	title = title or contents
	# if only title is given, contents is title
	contents = contents or title
	argdict = {
	    'type': 'radio',
	    'name': self.fieldname,
	    'value': contents,
	    }
	if value == contents:
	    argdict['checked'] = None
	
	return Utils.html_tag('input', argdict, title)
    
    def render(self, value):
	"""Render this field.
	"""
	props = self.props

	# do basic layout
	result = StringIO()
	result.write('<table border="0">\n')
	for i in range(len(props.data)):
	    result.write("<tr><td>")
	    result.write(self.render_part(i, value))
	    result.write("</td></tr>\n")
	result.write("</table>")
	
	return result.getvalue()

    def process(self, REQUEST):
	"""Process what's entered.
	"""
	props = self.props
	if REQUEST.has_key(self.fieldname):
	    input = REQUEST[self.fieldname]
	else:
	    input = ""

	# check if data was entered while required
	input = string.strip(input)
	if props.required and input == "":
	    raise ValidationError, "required_not_found"

	REQUEST.set(self.fieldname, input)
