from Field import Field, ValidationError
import string
import Utils

class StringBaseField(Field):
    """Base class for fields that use input type=text
    """

    def __init__(self, id, title, 
		 visual_length, visual_max_length, required, default):
	"""Initialize.
	id - id of field
	title - description of field
	"""
	Field.__init__(self, id, title)
	# set properties
	props = self.props
	props.visual_length = visual_length
	props.visual_max_length = visual_max_length
	props.required = required
	props.default = default
	self.props = props
	
	self._addMessage('required_not_found',
			 'Input required but no input given')
	
    def render(self, value):
	"""Render this field.
	"""
	props = self.props
	argdict = {
	    'type' : 'text',
	    'name' : self.fieldname,
	    'value' : value,
	    'size' : props.visual_length,
	    }
	if props.visual_max_length > 0:
	    argdict['maxlength'] = props.visual_max_length
	
	return Utils.html_tag('input', argdict)

    def process(self, REQUEST):
	"""Process what's entered.
	"""
	props = self.props
	input = REQUEST[self.fieldname]
	
	# check if data was entered while required
	input = string.strip(input)
	if props.required and input == "":
	    raise ValidationError, "required_not_found"
	REQUEST.set(self.fieldname, input)
