__doc__ = """
ZFormulator initialization module.

Import the modules of the fields you want to add to the ZFormulator system,
and their respective sheet modules. Add them to the system using the
Register function. 

Errors may cause the product to be broken (see the traceback in ZFormulator's
product folder in that case). Uncaught errors are outputted to stderr, so 
check there too if things don't work.
"""

__version__ = '0.1'

# import the fields and sheets we want to be addable to the form
import BasicField, BasicFieldSheet
import StringField, StringFieldSheet
import IntegerField, IntegerFieldSheet
import RangedIntegerField, RangedIntegerFieldSheet
import CheckboxField, CheckboxFieldSheet
import TextareaField, TextareaFieldSheet
import ListField, ListFieldSheet
import RadioField, RadioFieldSheet

# import the form
import Form

def initialize(context): 
    """Initialize all the products defined in this Product distribution.
    """
    try:
	# register all fields that can be added to the Form
	Form.registerField(BasicField.BasicField,
			   BasicFieldSheet.sheet,
			   "BasicField.gif")
	Form.registerField(StringField.StringField,
			   StringFieldSheet.sheet,
			   "StringField.gif")
	Form.registerField(IntegerField.IntegerField,
			   IntegerFieldSheet.sheet,
			   "IntegerField.gif")
	Form.registerField(RangedIntegerField.RangedIntegerField,
			   RangedIntegerFieldSheet.sheet,
			   "RangedIntegerField.gif")
	Form.registerField(CheckboxField.CheckboxField,
			   CheckboxFieldSheet.sheet,
			   "CheckboxField.gif")
	Form.registerField(TextareaField.TextareaField,
			   TextareaFieldSheet.sheet,
			   "TextareaField.gif")
	Form.registerField(ListField.ListField,
			   ListFieldSheet.sheet,
			   "ListField.gif")
	Form.registerField(RadioField.RadioField,
			   RadioFieldSheet.sheet,
			   "ListField.gif")
	
	# try to register the ZFormulatorForm class
	context.registerClass(
	    Form.Form,
	    constructors = (
		Form.manage_addformForm,
		Form.manage_addform
		),
	    icon = "ZFormulatorForm.gif"
	    )
    except:
	# throw all exceptions on stderr
	import sys, traceback, string
	type, val, tb = sys.exc_info()
	sys.stderr.write(string.join(traceback.\
				     format_exception(type, val, tb), ''))
	del type, val, tb  
